@@ -247,6 +247,7 @@ func createNbdKitWrapper(vmware *VMwareClient, diskFileName string) (*NbdKitWrap
 // VMwareConnectionOperations provides a mockable interface for the things needed from VMware client objects.
 type VMwareConnectionOperations interface {
 	Logout(context.Context) error
+	IsVC() bool
 }
 
 // VMwareVMOperations provides a mockable interface for the things needed from VMware VM objects.
@@ -291,12 +292,14 @@ func createVMwareClient(endpoint string, accessKey string, secKey string, thumbp
 	conn, err := govmomi.NewClient(ctx, vmwURL, true)
 	if err != nil {
 		klog.Errorf("Unable to connect to vCenter: %v", err)
+		cancel()
 		return nil, err
 	}
 
 	moref, vm, err := FindVM(ctx, conn, uuid)
 	if err != nil {
 		klog.Errorf("Unable to find MORef for VM with UUID %s!", uuid)
+		cancel()
 		return nil, err
 	}
 
@@ -458,8 +461,22 @@ func FindVM(context context.Context, conn *govmomi.Client, uuid string) (string,
 // MaxBlockStatusLength limits the maximum block status request size to 2GB
 const MaxBlockStatusLength = (2 << 30)
 
-// MaxPreadLength limits individual data block transfers to 23MB, larger block sizes fail
-const MaxPreadLength = (23 << 20)
+// MaxPreadLengthESX limits individual VDDK data block transfers to 23MB.
+// Larger block sizes fail immediately.
+const MaxPreadLengthESX = (23 << 20)
+
+// MaxPreadLengthVC limits indidivual VDDK data block transfers to 2MB only when
+// connecting to vCenter. With vCenter endpoints, multiple simultaneous importer
+// pods with larger read sizes cause allocation failures on the server, and the
+// imports start to fail:
+//         "NfcFssrvrProcessErrorMsg: received NFC error 5 from server:
+//          Failed to allocate the requested 24117272 bytes"
+const MaxPreadLengthVC = (2 << 20)
+
+// MaxPreadLength is the maxmimum read size to request from VMware. Default to
+// the larger option, and reduce it in createVddkDataSource when connecting to
+// vCenter endpoints.
+var MaxPreadLength uint32 = MaxPreadLengthESX
 
 // NbdOperations provides a mockable interface for the things needed from libnbd.
 type NbdOperations interface {
@@ -586,7 +603,7 @@ func CopyRange(handle NbdOperations, sink VDDKDataSink, block *BlockStatusData,
 		return err
 	}
 
-	buffer := bytes.Repeat([]byte{0}, MaxPreadLength)
+	buffer := bytes.Repeat([]byte{0}, int(MaxPreadLength))
 	count := uint32(0)
 	for count < block.Length {
 		if block.Length-count < MaxPreadLength {
@@ -845,6 +862,12 @@ func createVddkDataSource(endpoint string, accessKey string, secKey string, thum
 		}
 	}
 
+	MaxPreadLength = MaxPreadLengthESX
+	if vmware.conn.IsVC() {
+		klog.Infof("Connected to vCenter, restricting read request size to %d.", MaxPreadLengthVC)
+		MaxPreadLength = MaxPreadLengthVC
+	}
+
 	source := &VDDKDataSource{
 		NbdKit:           nbdkit,
 		ChangedBlocks:    changed,
@@ -853,6 +876,14 @@ func createVddkDataSource(endpoint string, accessKey string, secKey string, thum
 		Size:             size,
 		VolumeMode:       volumeMode,
 	}
+
+	terminationChannel := newTerminationChannel()
+	go func() {
+		<-terminationChannel
+		klog.Infof("Caught termination signal, closing nbdkit.")
+		source.Close()
+	}()
+
 	return source, nil
 }
 
@@ -865,7 +896,10 @@ func (vs *VDDKDataSource) Info() (ProcessingPhase, error) {
 // Close closes any readers or other open resources.
 func (vs *VDDKDataSource) Close() error {
 	vs.NbdKit.Handle.Close()
-	return vs.NbdKit.Command.Process.Kill()
+	if vs.NbdKit.Command.Process != nil {
+		return vs.NbdKit.Command.Process.Signal(os.Interrupt)
+	}
+	return nil
 }
 
 // GetURL returns the url that the data processor can use when converting the data.
